# django-datadownloader

## Description

This django app is an app tool that add an admin interface for manage archives
of database's json dumps and/or media datas.

For the moment, this app use the script build by the
[emencia-recipe-drdump](https://pypi.python.org/pypi/emencia-recipe-drdump)
package (we must improve it for directly use
[dr-dump](https://github.com/emencia/dr-dump) package)

## Links
* Pypi page: https://pypi.python.org/pypi/django-datadownloader
* Github page: https://github.com/emencia/django-datadownloader
